# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77
#
# (C) Copyright IBM Corp. 2005 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***

#
# Description:
#
#   This script creates a .tar.Z file containing the logs and
#   configuration files for KD4.  It leaves the file in the working
#   directory where the script was invoked from.  The file name is in
#   the form:
#
#     KD4PDDC.<date>.<time>.tar.Z
#

set_up() {
    dateSuffix=`date +%Y%m%d.%H%M%S`
    bundleFileName=KD4PDDC.$dateSuffix.tar
    envFileName=/tmp/KD4PDDCEnv.$dateSuffix.txt
    platform=`uname`
}

find_KD4_home() {
    KD4_CONFIG="/etc/KD4BaseDirConfig.properties"
    if [ -f "$KD4_CONFIG" ]
    then
       . $KD4_CONFIG
       if [ -d "$INSTALLDIR" ]
       then
           export INSTALLDIR
       else
           echo "Error: $INSTALLDIR not found"
           rc=111
       fi
    else
        echo "Error: $KD4_CONFIG not found"
        rc=111
    fi
}

capture_env() {
    echo \*\*\* uname -a: > $envFileName
    uname -a >> $envFileName
    echo >> $envFileName

    echo \*\*\* df: >> $envFileName
    df >> $envFileName
    echo >> $envFileName

    echo \*\*\* ulimit: >> $envFileName
    ulimit >> $envFileName
    echo >> $envFileName

    echo \*\*\* id: >> $envFileName
    id >> $envFileName
    echo >> $envFileName

    echo \*\*\* logs contents: >> $envFileName
    find $INSTALLDIR/KD4/logs -type f -ls -name \* -print >> $envFileName
    echo >> $envFileName

    echo \*\*\* config contents: >> $envFileName
    find $INSTALLDIR/KD4/config -type f -ls -name \* -print >> $envFileName
}

build_bundle() {
    find $INSTALLDIR/../../logs -name \*_d4_\*.log -print > /tmp/kd4pddc.ddf
    find $INSTALLDIR/KD4 -name \*.properties -print >> /tmp/kd4pddc.ddf
    find $INSTALLDIR/KD4/logs -type f -name \* -print | grep -v content >> /tmp/kd4pddc.ddf
    if [ -f "/tmp/operations.log" ]
    then
      echo /tmp/operations.log >> /tmp/kd4pddc.ddf
    fi
    if [ -f "/tmp/trace.log" ]
    then
      echo /tmp/trace.log >> /tmp/kd4pddc.ddf
    fi
    echo $envFileName >> /tmp/kd4pddc.ddf
    if [ "$platform" == "SunOS" ]
    then
      tar -cf $bundleFileName -I /tmp/kd4pddc.ddf
    else
      tar -cf $bundleFileName -L /tmp/kd4pddc.ddf
    fi
    compress $bundleFileName
    if [ -f "$bundleFileName.Z" ]
    then
      echo Success: $bundleFileName.Z created in the current directory.
    else
      echo Failure: $bundleFileName.Z was not created.
    fi
}

clean_up() {
    rm $envFileName
    rm /tmp/kd4pddc.ddf
}

######################## mainline ######################

rc=0;

find_KD4_home

if [ "$rc" == "0" ]
then
  set_up
  capture_env
  build_bundle
  clean_up
fi

exit $rc;