#!/bin/sh
# ****************************************************** {COPYRIGHT-TOP} ***
# Licensed Materials - Property of IBM
# 5724-M07, 5698-A77
#
# (C) Copyright IBM Corp. 2005,2006 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication, or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ****************************************************** {COPYRIGHT-END} ***
################## subroutine definitions ###############

general_syntax() {
    echo "Usage: $0 [-enable|-disable] -env [1|2|3|4|6|7|8|9] <server_specific_options>"
    echo "   Application server environments:"
    echo "      1 = IBM WebSphere Application Server"
    echo "      2 = Microsoft ASP.NET"
    echo "      3 = BEA WebLogic Application Server"
    echo "      4 = JBoss Application Server"
    echo "      6 = SAP NetWeaver Server"
    echo "      7 = IBM Websphere Application Server Community Edition"
    echo "      8 = DataPower"
    echo "      9 = Service Component Architecture (SCA) monitoring in WESB and WPS"

    rc=100;
}

find_KD4_home() {
    KD4_CONFIG="/etc/KD4BaseDirConfig.properties"
    if [ -f "$KD4_CONFIG" ]
    then
       . $KD4_CONFIG
       if [ -d "$INSTALLDIR" ]
       then
           echo "KD4 Home Dir = $INSTALLDIR"
           export INSTALLDIR
       else
           echo "Error: $INSTALLDIR not found" 
           rc=111
       fi
    else
        echo "Error: $KD4_CONFIG not found"
        rc=111
    fi
}

call_WAS_script()
{
    if [ ! "$ACTION" ] || [ "$ARG4" = "-h" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 1 (<WAS_HOME>)"
        rc=100;
    else
        if [ ! "$ARG4" ]
        then
            ARG4="USE_ENV_VAR"
        fi

        cmd="sh $INSTALLDIR/KD4/bin/configWASDC.sh $ACTION $ARG4" 
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configWASDC.sh = $rc"
    fi
}

call_NET_script()
{
    OS=`uname`
    echo "Error:  Microsoft ASP.NET environment not supported on $OS"
    rc=114;
}

call_BEA_script()
{
    if [ ! "$ARG6" ]
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 3 <URL> <userid> <password>"
        rc=100;
    else
        cmd="sh $INSTALLDIR/KD4/bin/configBEADC.sh $ACTION $ARG4 $ARG5 $ARG6 $INSTALLDIR"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configBEADC.sh = $rc"
    fi
}

# call the configDPDC.sh script.
call_DP_script()
{
   # min args: -action -env 8 -host hostName -user userName
 
   if [ ! "$ARG7" ] 
   then
      echo "Syntax: KD4configDC [-enable | -disable] -env 8 -host hostName -user userName (-pswd password -port port -path urlPath -poll pollInterval -domainlist \"domain1,domain2,...\" -displaygroup groupName"
      rc=100;
   else
        PROP_FILE=$INSTALLDIR/KD4/config/KD4.dpdcConfig.properties;

        # pull in the rest of the keys and values (4th arg to the end)
        KEY_VALUE_ARGS=`echo $ALL_ARGS | cut -f4- -d" "`

        cmd="sh $INSTALLDIR/KD4/bin/configDPDC.sh $ACTION $INSTALLDIR $PROP_FILE $KEY_VALUE_ARGS"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configDPDC.sh = $rc"
    fi
      
}

call_SCA_script()
{
    if [ ! "$ACTION" ] || [ "$ARG4" = "-h" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 9 (<WESB_HOME> | <WPS_HOME>)"
        rc=100;
    else
        if [ ! "$ARG4" ]
        then
            ARG4="USE_ENV_VAR"
        fi

        cmd="sh $INSTALLDIR/KD4/bin/configSCADC.sh $ACTION $ARG4" 
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configSCADC.sh = $rc"
    fi
}

# call configJBOSSDC.sh script
call_JBOSS_script()
{
    if [ ! "$ARG4" ] 
    then
        echo "Syntax: KD4configDC [-enable|-disable] -env 4 <server_name> <JBOSS_HOME>"
        echo "     server_name : Name of server need to be configured"
	echo "     JBOSS_HOME : The path name where JBOSS installed into, optional. If user already exported the JBOSS_HOME into environment, it's not required. Otherwise, user must provide that when running the script."
        rc=100;
    else
    	if [ ! "$ARG5" ]
    	then 
    		echo $ARG5
    		ARG5="USE_ENV_HOME"
    		echo $ARG5
    	fi
        cmd="sh $INSTALLDIR/KD4/bin/configJBOSSDC.sh $ACTION $ARG4 $INSTALLDIR $ARG5"
        echo "Configuration command = $cmd"
        $cmd
        rc=$?
        echo "Return code from configJBOSSDC.sh = $rc"
    fi
}

# call configWASCEDC.sh script
call_WASCEDC_script()
{
   OS_Name=`uname` 
   if [ "$OS_Name" != "Linux" ] 
   then
      echo "WASCE Data Collector cannot be enabled on the current operating system. "
      echo "Only Windows and Linux are currently supported. "
      rc=100
   else
   if [ "$ARG4" = "-user" ]
   #if user doesn't input wasce home dir as parameter, just retrive environment variable $WASCE_HOME
   then
      ARG11=$ARG10
      ARG10=$ARG9
      ARG9=$ARG8
      ARG8=$ARG7
      ARG7=$ARG6
      ARG6=$ARG5
      ARG5=$ARG4
      ARG4=$WASCE_HOME
      NUM_ARG=`expr $NUM_ARG + 1`
   fi
   echo "arg4=$ARG4"

   if [ "$NUM_ARG" -eq "10" ]
   then
      if [ ! "$ARG6" ] || [ ! "$ARG8" ] || [ "$ARG5" != "-user" ] || [ "$ARG7" != "-passwd" ] || [ "$ARG9" != "-file" ]
      then
         call_WASCE_syntax
    	 rc=100
      else
         #if user just input -file only ,pass $ARG10 which is filename
         cmd="sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION $ARG4 $ARG6 $ARG8 $INSTALLDIR $ARG10"
	 echo "Configuration command = $cmd"
	 sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION "$ARG4" $ARG6 $ARG8 "$INSTALLDIR" "$ARG10"
	 rc=$?
	 echo "Return code from configWASCEDC.sh = $rc"
      fi
   elif [ "$NUM_ARG" -eq "11" ]
   then
      if [ ! "$ARG6" ] || [ ! "$ARG8" ] || [ "$ARG5" != "-user" ] || [ "$ARG7" != "-passwd" ] || [ "$ARG9" != "-list" ] || [ "$ARG10" != "-file" ]
      then
         call_WASCE_syntax
    	 rc=100
      else
         #if user input -list -file, pass $ARG11 which is filename and $ARG9 which is -list
         cmd="sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION $ARG4 $ARG6 $ARG8 $INSTALLDIR $ARG11 $ARG9"
         echo "Configuration command = $cmd"
         sh $INSTALLDIR/KD4/bin/configWASCEDC.sh $ACTION "$ARG4" $ARG6 $ARG8 "$INSTALLDIR" "$ARG11" $ARG9
	 rc=$?
	 echo "Return code from configWASCEDC.sh = $rc"
      fi        	
   else
      call_WASCE_syntax
      rc=100
   fi				
   fi
}

# call configSAPDC.sh script
call_SAP_script()
{
    if [ ! "$ARG4" ] || [ ! "$ARG5" ] 
    then
        call_SAP_syntax;
        echo ""
        echo ""
        rc=201
        echo "Return code = $rc"
    else

    	if  [ "$ARG4" != "-sapappsdir" ] && [ "$ARG4" != "-clientappsdir" ] && [ "$ARG4" != "-sid" ] 
    	then 
                call_SAP_syntax;
                echo ""
                echo ""
                rc=201
                echo "Return code = $rc"
    	else
		if  [ "$ARG4" = "-sapappsdir" ] &&  [ "$NUM_ARG" = "5" ] 
        	then
			cmd="sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 \"$ARG5\""
			echo "Configuration command = $cmd"
			sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 "$ARG5"
			rc=$?
		elif [ "$ARG4" = "-clientappsdir" ] && [ "$NUM_ARG" = "5" ] 
		then
			cmd="sh $INSTALLDIR/KD4/bin/configSAPClientDC.sh $ACTION $ARG4 \"$ARG5\""
			echo "Configuration command = $cmd"
			sh $INSTALLDIR/KD4/bin/configSAPClientDC.sh $ACTION $ARG4 "$ARG5"
			rc=$? 
		elif [ "$ARG4" = "-sid" ] && [ "$NUM_ARG" = "6" ] 
		then 
			cmd="sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 $ARG5 \"$ARG6\""
			echo "Configuration command = $cmd"
			sh $INSTALLDIR/KD4/bin/configSAPDC.sh $ACTION $ARG4 $ARG5 "$ARG6" 
		else
			call_SAP_syntax;
               	 	echo ""
                	echo ""
                	rc=201
                	echo "Return code = $rc"
		        return

		fi
        	        	
		if  [ "$ARG4" = "-sapappsdir"  ]  || [ "$ARG4" = "-sid" ]  
        	then
			echo "Return code from configSAPDC.sh = $rc"
		else
			echo "Return code from configSAPClientDC.sh = $rc"
		fi				
    	fi
    fi
}

call_WASCE_syntax(){
   echo "Syntax: KD4configDC [-enable|-disable] -env 7 <WASCE_HOME>  -user {user_name} -passwd {passwd} [-list] -file <filename>"
   echo "     WASCE_HOME :  The path name where WASCE installed into, optional. If user already exported the WASCE_HOME into environment, it's not required. Otherwise, user must provide that when running the script."
   echo "     user_name  :  WASCE administrator user id"
   echo "     passwd     :  password of administrator"
   echo "     -list      :  Used for generating applications list file only"	
   echo "     filename   :  The relative file to current directory which contains the list of applications"
}

call_SAP_syntax(){
echo "KD4CF0051W Before running this utility, refer to the documentation for details about enabling applications in the SAP NetWeaver environment."
}

######################## mainline ######################
ACTION=$1
ENV_KEY=$2
ENV_TYPE=$3
ARG4=$4
ARG5=$5
ARG6=$6
ARG7=$7
ARG8=$8
ARG9=$9
ALL_ARGS=$*
NUM_ARG=$#

if [ "$NUM_ARG" -eq "10" ]
then
    shift
    ARG10=$9
    ARG11=""
elif [ "$NUM_ARG" -eq "11" ]
then
    shift
    shift
    ARG10=$8
    ARG11=$9
else
    ARG10=""
    ARG11=""
fi

rc=0;

if [ "$ENV_KEY" != "-env" ] 
then
   general_syntax 
   exit $rc
fi  

if [ "$ACTION" != "-enable" ] && [ "$ACTION" != "-disable" ]
then
   general_syntax 
   exit $rc
fi  


find_KD4_home

case $ENV_TYPE in
    1) call_WAS_script ;;
    2) call_NET_script ;;
    3) call_BEA_script ;;
    4) call_JBOSS_script ;;
    6) call_SAP_script ;;
    7) call_WASCEDC_script ;;
    8) call_DP_script ;;
    9) call_SCA_script ;;
    *) general_syntax ;;
esac

exit $rc;
